@@ -2,7 +2,7 @@
 //
 // pgAgent - PostgreSQL Tools
 //
-// Copyright (C) 2002 - 2018, The pgAdmin Development Team
+// Copyright (C) 2002 - 2021, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
 // unix.cpp - pgAgent unix specific functions
@@ -24,13 +24,12 @@ using namespace std;
 
 void printVersion();
 
-void usage(const std::wstring &executable)
+void usage(const std::string &appName)
 {
-	char *appName = WStringToChar(executable);
 	printVersion();
 
 	fprintf(stdout, "Usage:\n");
-	fprintf(stdout, "%s [options] <connect-string>\n", appName);
+	fprintf(stdout, "%s [options] <connect-string>\n", appName.c_str());
 	fprintf(stdout, "options:\n");
 	fprintf(stdout, "-v (display version info and then exit)\n");
 	fprintf(stdout, "-f run in the foreground (do not detach from the terminal)\n");
@@ -38,14 +37,11 @@ void usage(const std::wstring &executable)
 	fprintf(stdout, "-r <retry period after connection abort in seconds (>=10, default 30)>\n");
 	fprintf(stdout, "-s <log file (messages are logged to STDOUT if not specified>\n");
 	fprintf(stdout, "-l <logging verbosity (ERROR=0, WARNING=1, DEBUG=2, default 0)>\n");
-
-	if (appName)
-		delete []appName;
 }
 
-void LogMessage(const std::wstring &msg, const int &level)
+void LogMessage(const std::string &msg, const int &level)
 {
-	std::wofstream out;
+	std::ofstream out;
 	bool writeToStdOut = false;
 	MutexLocker locker(&s_loggerLock);
 
@@ -64,45 +60,33 @@ void LogMessage(const std::wstring &msg, const int &level)
 
 	boost::gregorian::date current_date(boost::gregorian::day_clock::local_day());
 
-	std::wstring day_week = boost::lexical_cast<std::wstring>(current_date.day_of_week());
-	std::wstring year = boost::lexical_cast<std::wstring>(current_date.year());
-	std::wstring month = boost::lexical_cast<std::wstring>(current_date.month());
-	std::wstring day = boost::lexical_cast<std::wstring>(current_date.day());
+	std::string day_week = boost::lexical_cast<std::string>(current_date.day_of_week());
+	std::string year = boost::lexical_cast<std::string>(current_date.year());
+	std::string month = boost::lexical_cast<std::string>(current_date.month());
+	std::string day = boost::lexical_cast<std::string>(current_date.day());
 
 	boost::posix_time::ptime pt = boost::posix_time::second_clock::local_time();
-	std::wstring time_day = boost::lexical_cast<std::wstring>(pt.time_of_day());
+	std::string time_day = boost::lexical_cast<std::string>(pt.time_of_day());
 
-	std::wstring logTimeString = L"";
-	logTimeString = day_week + L" " + month + L" " + day + L" " + time_day + L" " + year + L" ";
+	std::string logTimeString = "";
+	logTimeString = day_week + " " + month + " " + day + " " + time_day + " " + year + " ";
 
 	switch (level)
 	{
 		case LOG_DEBUG:
 			if (minLogLevel >= LOG_DEBUG)
-			{
-				logTimeString = logTimeString + L"DEBUG: " + msg + L"\n";
-				if (writeToStdOut)
-					std::wcout << logTimeString;
-				else
-					out.write(logTimeString.c_str(), logTimeString.size());
-			}
+				(writeToStdOut ? std::cout : out) << logTimeString <<
+					"DEBUG: " << msg << std::endl;
 			break;
 		case LOG_WARNING:
 			if (minLogLevel >= LOG_WARNING)
-			{
-				logTimeString = logTimeString + L"WARNING: " + msg + L"\n";
-				if (writeToStdOut)
-					std::wcout << logTimeString;
-				else
-					out.write(logTimeString.c_str(), logTimeString.size());
-			}
+				(writeToStdOut ? std::cout : out) << logTimeString <<
+					"WARNING: " << msg << std::endl;
 			break;
 		case LOG_ERROR:
-			logTimeString = logTimeString + L"ERROR: " + msg + L"\n";
-			if (writeToStdOut)
-				std::wcout << logTimeString;
-			else
-				out.write(logTimeString.c_str(), logTimeString.size());
+			(writeToStdOut ? std::cout : out) << logTimeString <<
+				"ERROR: " << msg << std::endl;
+
 			// On system exit, boost::mutex object calls
 			// pthread_mutex_destroy(...) on the underlying native mutex object.
 			// But - it returns errorcode 'BUSY' instead of 0. Because - it was
@@ -114,11 +98,8 @@ void LogMessage(const std::wstring &msg, const int &level)
 			exit(1);
 			break;
 		case LOG_STARTUP:
-			logTimeString = logTimeString + L"WARNING: " + msg + L"\n";
-			if (writeToStdOut)
-				std::wcout << logTimeString;
-			else
-				out.write(logTimeString.c_str(), logTimeString.size());
+			(writeToStdOut ? std::cout : out) << logTimeString <<
+				"WARNING: " << msg << std::endl;
 			break;
 	}
 
@@ -137,7 +118,7 @@ static void daemonize(void)
 	pid = fork();
 	if (pid == (pid_t)-1)
 	{
-		LogMessage(L"Cannot disassociate from controlling TTY", LOG_ERROR);
+		LogMessage("Cannot disassociate from controlling TTY", LOG_ERROR);
 		exit(1);
 	}
 	else if (pid)
@@ -146,7 +127,7 @@ static void daemonize(void)
 #ifdef HAVE_SETSID
 	if (setsid() < 0)
 	{
-		LogMessage(L"Cannot disassociate from controlling TTY", LOG_ERROR);
+		LogMessage("Cannot disassociate from controlling TTY", LOG_ERROR);
 		exit(1);
 	}
 #endif
@@ -155,8 +136,10 @@ static void daemonize(void)
 
 int main(int argc, char **argv)
 {
-	std::wstring executable;
-	executable.assign(CharToWString(argv[0]));
+	setlocale(LC_ALL, "");
+
+	std::string executable;
+	executable.assign(argv[0]);
 
 	if (argc < 2)
 	{
